==> cscec5b-wzxt-api-3.0.0-20210803.083941-296-sources.jar: com/ejianc/business/wzxt/vo/SupplierEvaluationVO.java <==
package com.ejianc.business.wzxt.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 供方评价表实体
 * 
 * @author generator
 * 
 */
public class SupplierEvaluationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long orgId; // 组织ID
    private java.lang.String orgSourceId; // 组织来源ID
    private java.lang.String orgName; // 组织名称
    private java.lang.Long parentOrgId; // 上级组织id
    private java.lang.String parentOrgSourceId; // 上级组织来源ID
    private java.lang.Long projectId; // 项目
    private java.lang.String projectSourceId; // 项目来源ID
    private java.lang.String projectName; // 项目名称
    private java.lang.Long supplierId; // 供方ID
    private java.lang.String supplierSourceId; // 供应商来源id
    private java.lang.String supplierName; // 供应商名称
    private java.lang.String contractName; // 合同名称
    private java.lang.Long contractId; // 合同主键
    private java.lang.String contractCode; // 合同编号
    private java.lang.String billCode; // 验收单编号
    private java.lang.Long employeeId; // 验收人ID
    private java.lang.String employeeName; // 验收人名称
    private java.lang.String materialName; // 材料名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date evaluateDate; // 评价时间
    private java.lang.String evaluatePerson; // 参评人员
    private java.lang.Integer evaluateSum; // 评价总得分
    private java.lang.String qualityEvaluate; // 质量评价
    private java.lang.Integer qualityScore; // 质量得分
    private java.lang.String numEvaluate; // 数量评价
    private java.lang.Integer numScore; // 数量得分
    private java.lang.String efficiencyEvaluate; // 时效评价
    private java.lang.Integer efficiencyScore; // 时效得分
    private java.lang.String serviceEvaluate; // 服务评价
    private java.lang.Integer serviceScore; // 服务得分
    private java.lang.String isPurchase; // 验收类型，0-其他，1-采购验收,2-周转材租赁,3-MRO
    private java.lang.Long checkId; // 验收单id

    public String getIsPurchase() {
        return isPurchase;
    }

    public void setIsPurchase(String isPurchase) {
        this.isPurchase = isPurchase;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }

    /**
     * 组织ID
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public java.lang.String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(java.lang.String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织id
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织id
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源ID
     */
    public java.lang.String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源ID
     */
    public void setParentOrgSourceId(java.lang.String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public java.lang.String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(java.lang.String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 供方ID
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 供方ID
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商来源id
     */
    public java.lang.String getSupplierSourceId() {
        return supplierSourceId;
    }

    /**
     * 供应商来源id
     */
    public void setSupplierSourceId(java.lang.String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同主键
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 验收单编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 验收单编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 验收人ID
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人ID
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 材料名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 评价时间
     */
    public java.util.Date getEvaluateDate() {
        return evaluateDate;
    }

    /**
     * 评价时间
     */
    public void setEvaluateDate(java.util.Date evaluateDate) {
        this.evaluateDate = evaluateDate;
    }
    /**
     * 参评人员
     */
    public java.lang.String getEvaluatePerson() {
        return evaluatePerson;
    }

    /**
     * 参评人员
     */
    public void setEvaluatePerson(java.lang.String evaluatePerson) {
        this.evaluatePerson = evaluatePerson;
    }
    /**
     * 评价总得分
     */
    public java.lang.Integer getEvaluateSum() {
        return evaluateSum;
    }

    /**
     * 评价总得分
     */
    public void setEvaluateSum(java.lang.Integer evaluateSum) {
        this.evaluateSum = evaluateSum;
    }
    /**
     * 质量评价
     */
    public java.lang.String getQualityEvaluate() {
        return qualityEvaluate;
    }

    /**
     * 质量评价
     */
    public void setQualityEvaluate(java.lang.String qualityEvaluate) {
        this.qualityEvaluate = qualityEvaluate;
    }
    /**
     * 质量得分
     */
    public java.lang.Integer getQualityScore() {
        return qualityScore;
    }

    /**
     * 质量得分
     */
    public void setQualityScore(java.lang.Integer qualityScore) {
        this.qualityScore = qualityScore;
    }
    /**
     * 数量评价
     */
    public java.lang.String getNumEvaluate() {
        return numEvaluate;
    }

    /**
     * 数量评价
     */
    public void setNumEvaluate(java.lang.String numEvaluate) {
        this.numEvaluate = numEvaluate;
    }
    /**
     * 数量得分
     */
    public java.lang.Integer getNumScore() {
        return numScore;
    }

    /**
     * 数量得分
     */
    public void setNumScore(java.lang.Integer numScore) {
        this.numScore = numScore;
    }
    /**
     * 时效评价
     */
    public java.lang.String getEfficiencyEvaluate() {
        return efficiencyEvaluate;
    }

    /**
     * 时效评价
     */
    public void setEfficiencyEvaluate(java.lang.String efficiencyEvaluate) {
        this.efficiencyEvaluate = efficiencyEvaluate;
    }
    /**
     * 时效得分
     */
    public java.lang.Integer getEfficiencyScore() {
        return efficiencyScore;
    }

    /**
     * 时效得分
     */
    public void setEfficiencyScore(java.lang.Integer efficiencyScore) {
        this.efficiencyScore = efficiencyScore;
    }
    /**
     * 服务评价
     */
    public java.lang.String getServiceEvaluate() {
        return serviceEvaluate;
    }

    /**
     * 服务评价
     */
    public void setServiceEvaluate(java.lang.String serviceEvaluate) {
        this.serviceEvaluate = serviceEvaluate;
    }
    /**
     * 服务得分
     */
    public java.lang.Integer getServiceScore() {
        return serviceScore;
    }

    /**
     * 服务得分
     */
    public void setServiceScore(java.lang.Integer serviceScore) {
        this.serviceScore = serviceScore;
    }
    
}

==> cscec5b-wzxt-api-3.0.0-20210806.093222-303-sources.jar: com/ejianc/business/wzxt/vo/SupplierEvaluationVO.java <==
package com.ejianc.business.wzxt.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 供方评价表实体
 * 
 * @author generator
 * 
 */
public class SupplierEvaluationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long orgId; // 组织ID
    private java.lang.String orgSourceId; // 组织来源ID
    private java.lang.String orgName; // 组织名称
    private java.lang.Long parentOrgId; // 上级组织id
    private java.lang.String parentOrgSourceId; // 上级组织来源ID
    private java.lang.Long projectId; // 项目
    private java.lang.String projectSourceId; // 项目来源ID
    private java.lang.String projectName; // 项目名称
    private java.lang.Long supplierId; // 供方ID
    private java.lang.String supplierSourceId; // 供应商来源id
    private java.lang.String supplierName; // 供应商名称
    private java.lang.String contractName; // 合同名称
    private java.lang.Long contractId; // 合同主键
    private java.lang.String contractCode; // 合同编号
    private java.lang.String billCode; // 验收单编号
    private java.lang.Long employeeId; // 验收人ID
    private java.lang.String employeeName; // 验收人名称
    private java.lang.String materialName; // 材料名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date evaluateDate; // 评价时间
    private java.lang.String evaluatePerson; // 参评人员
    private java.lang.Integer evaluateSum; // 评价总得分
    private String qualityEvaluate; // 质量评价
    private Integer qualityScore; // 质量得分
    private String numEvaluate; // 数量评价
    private Integer numScore; // 数量得分
    private String efficiencyEvaluate; // 时效评价
    private Integer efficiencyScore; // 时效得分
    private String serviceEvaluate; // 服务评价
    private Integer serviceScore; // 服务得分
    private java.lang.String isPurchase; // 验收类型，0-其他，1-采购验收,2-周转材租赁,3-MRO
    private java.lang.Long checkId; // 验收单id

    public String getIsPurchase() {
        return isPurchase;
    }

    public void setIsPurchase(String isPurchase) {
        this.isPurchase = isPurchase;
    }

    public Long getCheckId() {
        return checkId;
    }

    public void setCheckId(Long checkId) {
        this.checkId = checkId;
    }

    /**
     * 组织ID
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织ID
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织来源ID
     */
    public java.lang.String getOrgSourceId() {
        return orgSourceId;
    }

    /**
     * 组织来源ID
     */
    public void setOrgSourceId(java.lang.String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 上级组织id
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织id
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织来源ID
     */
    public java.lang.String getParentOrgSourceId() {
        return parentOrgSourceId;
    }

    /**
     * 上级组织来源ID
     */
    public void setParentOrgSourceId(java.lang.String parentOrgSourceId) {
        this.parentOrgSourceId = parentOrgSourceId;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目来源ID
     */
    public java.lang.String getProjectSourceId() {
        return projectSourceId;
    }

    /**
     * 项目来源ID
     */
    public void setProjectSourceId(java.lang.String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 供方ID
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 供方ID
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商来源id
     */
    public java.lang.String getSupplierSourceId() {
        return supplierSourceId;
    }

    /**
     * 供应商来源id
     */
    public void setSupplierSourceId(java.lang.String supplierSourceId) {
        this.supplierSourceId = supplierSourceId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 合同主键
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同编号
     */
    public java.lang.String getContractCode() {
        return contractCode;
    }

    /**
     * 合同编号
     */
    public void setContractCode(java.lang.String contractCode) {
        this.contractCode = contractCode;
    }
    /**
     * 验收单编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 验收单编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 验收人ID
     */
    public java.lang.Long getEmployeeId() {
        return employeeId;
    }

    /**
     * 验收人ID
     */
    public void setEmployeeId(java.lang.Long employeeId) {
        this.employeeId = employeeId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 验收人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 材料名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 评价时间
     */
    public java.util.Date getEvaluateDate() {
        return evaluateDate;
    }

    /**
     * 评价时间
     */
    public void setEvaluateDate(java.util.Date evaluateDate) {
        this.evaluateDate = evaluateDate;
    }
    /**
     * 参评人员
     */
    public java.lang.String getEvaluatePerson() {
        return evaluatePerson;
    }

    /**
     * 参评人员
     */
    public void setEvaluatePerson(java.lang.String evaluatePerson) {
        this.evaluatePerson = evaluatePerson;
    }
    /**
     * 评价总得分
     */
    public java.lang.Integer getEvaluateSum() {
        return evaluateSum;
    }

    /**
     * 评价总得分
     */
    public void setEvaluateSum(java.lang.Integer evaluateSum) {
        this.evaluateSum = evaluateSum;
    }

    public String getQualityEvaluate() {
        return qualityEvaluate;
    }

    public void setQualityEvaluate(String qualityEvaluate) {
        this.qualityEvaluate = qualityEvaluate;
    }

    public Integer getQualityScore() {
        return qualityScore;
    }

    public void setQualityScore(Integer qualityScore) {
        this.qualityScore = qualityScore;
    }

    public String getNumEvaluate() {
        return numEvaluate;
    }

    public void setNumEvaluate(String numEvaluate) {
        this.numEvaluate = numEvaluate;
    }

    public Integer getNumScore() {
        return numScore;
    }

    public void setNumScore(Integer numScore) {
        this.numScore = numScore;
    }

    public String getEfficiencyEvaluate() {
        return efficiencyEvaluate;
    }

    public void setEfficiencyEvaluate(String efficiencyEvaluate) {
        this.efficiencyEvaluate = efficiencyEvaluate;
    }

    public Integer getEfficiencyScore() {
        return efficiencyScore;
    }

    public void setEfficiencyScore(Integer efficiencyScore) {
        this.efficiencyScore = efficiencyScore;
    }

    public String getServiceEvaluate() {
        return serviceEvaluate;
    }

    public void setServiceEvaluate(String serviceEvaluate) {
        this.serviceEvaluate = serviceEvaluate;
    }

    public Integer getServiceScore() {
        return serviceScore;
    }

    public void setServiceScore(Integer serviceScore) {
        this.serviceScore = serviceScore;
    }
}
